==> lms-1.0pre1.tar.gz: lms/lib/leftmenu.php <==
<? // $Id: leftmenu.php,v 1.22 2002/12/13 03:02:07 lukasz Exp $

/*
 * LMS version 1.0
 *
 *  (C) Copyright 2002 Rulez.PL Development Team
 *  (C) Copyright 2001-2002 NetX ACN
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: leftmenu.php,v 1.22 2002/12/13 03:02:07 lukasz Exp $
 */

// Array with left menu on engine.

$menu = Array();

$menu[name]	[] = "Witamy !";
$menu[img]	[] = "l.gif";
$menu[link]	[] = "?";
$menu[accesskey][] = "";

$menu[name]	[] = "Uytkownicy";
$menu[img]	[] = "user.gif";
$menu[link]	[] = "?m=userlist";
$menu[accesskey][] = "u";

$menu[name]	[] = "Komputery";
$menu[img]	[] = "node.gif";
$menu[link]	[] = "?m=nodelist";
$menu[accesskey][] = "k";

$menu[name]	[] = "Sieci IP";
$menu[img]	[] = "ip.gif";
$menu[link]	[] = "?m=netlist";
$menu[accesskey][] = "s";

$menu[name]	[] = "Taryfy";
$menu[img]	[] = "money.gif";
$menu[link]	[] = "?m=tarifflist";
$menu[accesskey][] = "t";

$menu[name]	[] = "Finanse";
$menu[img]	[] = "money.gif";
$menu[link]	[] = "?m=balancelist";
$menu[accesskey][] = "f";

$menu[name]	[] = "Mailing";
$menu[img]	[] = "mail.gif";
$menu[link]	[] = "?m=mailing";
$menu[accesskey][] = "m";

$menu[name]	[] = "Przeadowanie";
$menu[img]	[] = "reload.gif";
$menu[link]	[] = "?m=reload";
$menu[accesskey][] = "r";

$menu[name]	[] = "Bazy danych";
$menu[img]	[] = "db.gif";
$menu[link]	[] = "?m=dblist";
$menu[accesskey][] = "b";

$menu[name]	[] = "Administratorzy";
$menu[img]	[] = "admins.gif";
$menu[link]     [] = "?m=adminlist";
$menu[accesskey][] = "d";

?>

==> lms-1.1.2b.tar.gz: lms/lib/leftmenu.php <==
<?php

/*
 * LMS version 1.1.2b
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: leftmenu.php,v 1.48 2003/08/24 13:12:54 lukasz Exp $
 */

// Array with left menu on engine.

$menu = Array();

$menu[name]	[] = "Witamy !";
$menu[img]	[] = "l.gif";
$menu[link]	[] = "?";
$menu[accesskey][] = "";
$menu[tip]	[] = "";

$menu[name]	[] = "Uytkownicy";
$menu[img]	[] = "user.gif";
$menu[link]	[] = "?m=userlist";
$menu[accesskey][] = "u";
$menu[tip]	[] = "Uytkownicy: lista, wyszukiwanie, dodanie nowego";

$menu[name]	[] = "Komputery";
$menu[img]	[] = "node.gif";
$menu[link]	[] = "?m=nodelist";
$menu[accesskey][] = "k";
$menu[tip]	[] = "Komputery: lista, wyszukiwanie, dodawanie";

$menu[name]	[] = "Sieci IP";
$menu[img]	[] = "ip.gif";
$menu[link]	[] = "?m=netlist";
$menu[accesskey][] = "s";
$menu[tip]	[] = "Zarzdzanie klasami adresowymi IP";

$menu[name]	[] = "Taryfy i finanse";
$menu[img]	[] = "money.gif";
$menu[link]	[] = "?m=tarifflist";
$menu[accesskey][] = "t";
$menu[tip]	[] = "Zarzdzanie taryfami oraz finansami sieci";

$menu[name]	[] = "Mailing";
$menu[img]	[] = "mail.gif";
$menu[link]	[] = "?m=mailing";
$menu[accesskey][] = "m";
$menu[tip]	[] = "";

$menu[name]	[] = "Przeadowanie";
$menu[img]	[] = "reload.gif";
$menu[link]	[] = "?m=reload";
$menu[accesskey][] = "r";
$menu[tip]	[] = "";

$menu[name]	[] = "Bazy danych";
$menu[img]	[] = "db.gif";
$menu[link]	[] = "?m=dblist";
$menu[accesskey][] = "b";
$menu[tip]	[] = "Zarzdzanie kopiami zapasowymi bazy danych";

$menu[name]	[] = "Administratorzy";
$menu[img]	[] = "admins.gif";
$menu[link]     [] = "?m=adminlist";
$menu[accesskey][] = "d";
$menu[tip]	[] = "Konta administratorw systemu";

/*
 * $Log: leftmenu.php,v $
 * Revision 1.48  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.47  2003/08/18 16:57:00  lukasz
 * - more cvs tags :>
 *
 */

?>
